@@ -398,26 +398,29 @@ Ext.define('MP.data.MetaData', {
             }
 
             if(info.dictionary) {
-                var dict;
+                var store;
 
                 if(Ext.isArray(info.dictionary)) {
-                    dict = {};
-                    Ext.each(info.dictionary, function(v) {
-                        dict[v[0]] = v[1];
-                    });
+                    store = info.dictionary;
                 } else {
-                    dict = info.dictionary;
-                }
+                    var sortby = 0; // key by default
+                    var dict = info.dictionary;
+
+                    store = [];
 
-                var store = [];
-                if(Ext.isArray(info.dictionary)) {
-                    Ext.each(info.dictionary, function(v) {
-                        store[store.length] = v;
-                    });
-                } else {
                     for(var k in dict) {
-                        store.push([k, dict[k]]);
+                        if(k == '__sort_by__') {
+                            sortby = (dict[k] == 'value' ? 1 : 0);
+                        } else {
+                            store.push([k, dict[k]]);
+                        }
                     }
+
+                    store.sort(function(a,b) {
+                        a = a[sortby];
+                        b = b[sortby];
+                        return a<b ? -1 : (a>b ? 1 : 0);
+                    });
                 }
 
                 Ext.apply(editor, {
